==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/infra/data-source-pool/core/src/test/java/org/apache/shardingsphere/infra/datasource/pool/destroyer/fixture/DataSourcePoolActiveDetectorFixture.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.datasource.pool.destroyer.fixture;

import org.apache.shardingsphere.infra.datasource.pool.destroyer.DataSourcePoolActiveDetector;
import org.apache.shardingsphere.test.fixture.jdbc.MockedDataSource;

import javax.sql.DataSource;
import java.sql.SQLException;

public final class DataSourcePoolActiveDetectorFixture implements DataSourcePoolActiveDetector {
    
    @Override
    public boolean containsActiveConnection(final DataSource dataSource) throws SQLException {
        try (MockedDataSource wrappedDataSource = dataSource.unwrap(MockedDataSource.class)) {
            return !wrappedDataSource.getOpenedConnections().isEmpty();
        }
    }
    
    @Override
    public String getType() {
        return MockedDataSource.class.getName();
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/infra/data-source-pool/core/src/test/java/org/apache/shardingsphere/infra/datasource/pool/destroyer/fixture/DataSourcePoolActiveDetectorFixture.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.datasource.pool.destroyer.fixture;

import org.apache.shardingsphere.infra.datasource.pool.destroyer.DataSourcePoolActiveDetector;
import org.apache.shardingsphere.test.infra.fixture.jdbc.MockedDataSource;

import javax.sql.DataSource;
import java.sql.SQLException;

public final class DataSourcePoolActiveDetectorFixture implements DataSourcePoolActiveDetector {
    
    @Override
    public boolean containsActiveConnection(final DataSource dataSource) throws SQLException {
        try (MockedDataSource wrappedDataSource = dataSource.unwrap(MockedDataSource.class)) {
            return !wrappedDataSource.getOpenedConnections().isEmpty();
        }
    }
    
    @Override
    public String getType() {
        return MockedDataSource.class.getName();
    }
}
